@@ -79,8 +79,8 @@ class BlueprintEditForm(forms.ModelForm):
 
     class Meta:
         model = DonationBlueprint
-        fields = ['name', 'exp_file_format', 'csv_delimiter', 'file_uploader', 'regex_path',
-                  'expected_fields']
+        fields = ['name', 'description', 'exp_file_format', 'csv_delimiter',
+                  'file_uploader', 'regex_path', 'expected_fields']
         widgets = {
             'expected_fields': forms.Textarea(attrs={'rows': 3}),
             'regex_path': forms.Textarea(attrs={'rows': 3}),
@@ -104,10 +104,11 @@ class ProcessingRuleForm(forms.ModelForm):
 
     class Meta:
         model = ProcessingRule
-        fields = ['execution_order', 'name', 'field', 'comparison_operator', 'comparison_value']
+        fields = ['execution_order', 'name', 'field', 'comparison_operator', 'comparison_value', 'replacement_value']
         widgets = {
             'field': TextInput(),
-            'comparison_value': Textarea(attrs={'cols': 60, 'rows': 2})
+            'comparison_value': Textarea(attrs={'cols': 60, 'rows': 1}),
+            'replacement_value': Textarea(attrs={'cols': 60, 'rows': 1}),
         }
 
 
